==> o365-3.0.1.tar.gz: o365/modules/o365_sso/src/Controller/UserLoginController.php <==
<?php

namespace Drupal\o365_sso\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Routing\TrustedRedirectResponse;
use Drupal\externalauth\ExternalAuth;
use Drupal\o365\AuthenticationService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\o365\GraphService;

/**
 * UserLoginController. Used when returned from the callback.
 *
 * This creates/updates the user and logs in the Drupal user.
 */
class UserLoginController extends ControllerBase {

  /**
   * Drupal\o365\GraphService definition.
   *
   * @var \Drupal\o365\GraphService
   */
  protected $graphService;

  /**
   * Drupal\o365\AuthenticationService definition.
   *
   * @var \Drupal\o365\AuthenticationService
   */
  protected $authenticationService;

  /**
   * The external auth service.
   *
   * @var \Drupal\externalauth\ExternalAuth
   */
  protected $externalAuth;

  /**
   * Constructs a new UserLoginController object.
   *
   * @param \Drupal\o365\GraphService $o365_graph
   *   The GraphService definition.
   * @param \Drupal\o365\AuthenticationService $authenticationService
   *   The AuthenticationService definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The EntityTypeManager definition.
   * @param \Drupal\externalauth\ExternalAuth $externalAuth
   *   The ExternalAuth definition.
   */
  public function __construct(GraphService $o365_graph, AuthenticationService $authenticationService, EntityTypeManagerInterface $entity_type_manager, ExternalAuth $externalAuth) {
    $this->graphService = $o365_graph;
    $this->authenticationService = $authenticationService;
    $this->entityTypeManager = $entity_type_manager;
    $this->externalAuth = $externalAuth;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('o365.graph'), $container->get('o365.authentication'), $container->get('entity_type.manager'), $container->get('externalauth.externalauth'));
  }

  /**
   * Login a user.
   *
   * @return \Drupal\Core\Routing\TrustedRedirectResponse
   *   The redirect to the set URL in config.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException|\Drupal\externalauth\Exception\ExternalAuthRegisterException|\GuzzleHttp\Exception\GuzzleException
   */
  public function login() {
    // Save the data from the url.
    $this->authenticationService->saveAuthDataFromUrl();

    // Get user data.
    $userData = $this->graphService->getGraphData('/me');

    // Get config and redirect url after login.
    $config = $this->config('o365.api_settings');
    $redirectUrl = $config->get('redirect_login');

    // Get user unique identifier.
    $o365_id = $userData['id'];
    $account = $this->externalAuth->load($o365_id, 'o365_sso');

    // Check for email match.
    if (!$account) {
      $email = $userData['userPrincipalName'];
      $account = $this->entityTypeManager->getStorage('user')
        ->loadByProperties(['mail' => $email]);
      $account = !empty($account) ? reset($account) : FALSE;
    }

    if ($account) {
      $this->externalAuth->linkExistingAccount($o365_id, 'o365_sso', $account);
    }

    // If we haven't found an account to link, create one from the data.
    if (!$account) {
      $accountData = [
        'name' => $userData['displayName'],
        'mail' => $userData['userPrincipalName'],
      ];
      $account = $this->externalAuth->register($o365_id, 'o365_sso', $accountData);
    }
    elseif ($account->isBlocked()) {
      $this->messenger()->addError(t('The requested account is blocked'));
      $response = new TrustedRedirectResponse('/user/login');
      return $response->send();
    }

    // Log the user in.
    $this->externalAuth->userLoginFinalize($account, $o365_id, 'o365_sso');

    // Return the redirect.
    $response = new TrustedRedirectResponse($redirectUrl);
    return $response->send();
  }

}

==> o365-3.0.8.tar.gz: o365/modules/o365_sso/src/Controller/UserLoginController.php <==
<?php

namespace Drupal\o365_sso\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\externalauth\ExternalAuth;
use Drupal\o365\AuthenticationService;
use Drupal\o365\GraphService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * UserLoginController. Used when returned from the callback.
 *
 * This creates/updates the user and logs in the Drupal user.
 */
class UserLoginController extends ControllerBase {

  /**
   * Drupal\o365\GraphService definition.
   *
   * @var \Drupal\o365\GraphService
   */
  protected $graphService;

  /**
   * Drupal\o365\AuthenticationService definition.
   *
   * @var \Drupal\o365\AuthenticationService
   */
  protected $authenticationService;

  /**
   * The external auth service.
   *
   * @var \Drupal\externalauth\ExternalAuth
   */
  protected $externalAuth;

  /**
   * Constructs a new UserLoginController object.
   *
   * @param \Drupal\o365\GraphService $o365_graph
   *   The GraphService definition.
   * @param \Drupal\o365\AuthenticationService $authenticationService
   *   The AuthenticationService definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The EntityTypeManager definition.
   * @param \Drupal\externalauth\ExternalAuth $externalAuth
   *   The ExternalAuth definition.
   */
  public function __construct(GraphService $o365_graph, AuthenticationService $authenticationService, EntityTypeManagerInterface $entity_type_manager, ExternalAuth $externalAuth) {
    $this->graphService = $o365_graph;
    $this->authenticationService = $authenticationService;
    $this->entityTypeManager = $entity_type_manager;
    $this->externalAuth = $externalAuth;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('o365.graph'), $container->get('o365.authentication'), $container->get('entity_type.manager'), $container->get('externalauth.externalauth'));
  }

  /**
   * Login a user.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirect to the set URL in config.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException|\Drupal\externalauth\Exception\ExternalAuthRegisterException|\GuzzleHttp\Exception\GuzzleException
   */
  public function login() {
    // Save the data from the url.
    $this->authenticationService->saveAuthDataFromUrl();

    // Get user data.
    $userData = $this->graphService->getGraphData('/me');

    // Get config and redirect url after login.
    $config = $this->config('o365.api_settings');
    $redirectUrl = $config->get('redirect_login');

    // Get user unique identifier.
    $o365_id = $userData['id'];
    $account = $this->externalAuth->load($o365_id, 'o365_sso');

    // Check for email match.
    if (!$account) {
      $email = $userData['userPrincipalName'];
      $account = $this->entityTypeManager->getStorage('user')
        ->loadByProperties(['mail' => $email]);
      $account = !empty($account) ? reset($account) : FALSE;
    }

    if ($account) {
      $this->externalAuth->linkExistingAccount($o365_id, 'o365_sso', $account);
    }

    // If we haven't found an account to link, create one from the data.
    if (!$account) {
      $accountData = [
        'name' => $userData['displayName'],
        'mail' => $userData['userPrincipalName'],
      ];
      $account = $this->externalAuth->register($o365_id, 'o365_sso', $accountData);
    }
    elseif ($account->isBlocked()) {
      $this->messenger()->addError(t('The requested account is blocked'));
      return $this->redirect('user.login');
    }

    // Log the user in.
    $this->externalAuth->userLoginFinalize($account, $o365_id, 'o365_sso');

    // Return the redirect.
    return new RedirectResponse($redirectUrl);
  }

}
